@@ -25,7 +25,8 @@ if (!defined('AUTH_USER')) {
 // Verify CSRF token for state-changing operations
 $action = $_POST['action'] ?? $_GET['action'] ?? 'get';
 if ($action !== 'get') {
-    $csrfToken = $_POST['csrf_token'] ?? '';
+    // Check for CSRF token in POST data first, then in X-CSRF-Token header
+    $csrfToken = $_POST['csrf_token'] ?? ($_SERVER['HTTP_X_CSRF_TOKEN'] ?? '');
     if (empty($csrfToken) || !hash_equals($_SESSION['csrf_token'] ?? '', $csrfToken)) {
         http_response_code(403);
         echo json_encode(['success' => false, 'error' => 'Invalid CSRF token']);
